@@ -479,7 +479,7 @@ gpk_watch_show_about_cb (GtkMenuItem *item, gpointer data)
 			       "license", license_trans,
 			       "wrap-license", TRUE,	
 			       "website-label", _("PackageKit Website"),
-			       "website", "www.packagekit.org",
+			       "website", "http://www.packagekit.org",
 			       "comments", "PackageKit",
 			       "authors", authors,
 			       "documenters", documenters,
@@ -1299,6 +1299,12 @@ gpk_watch_process_messages_cb (PkMessage *item, GpkWatch *watch)
 		      "details", &details,
 		      NULL);
 
+	/* this is message unrecognised */
+	if (gpk_message_enum_to_localised_text (type) == NULL) {
+		egg_warning ("message unrecognized, and thus ignored: %i", type);
+		goto out;
+	}
+
 	/* is ignored */
 	ret = gpk_watch_is_message_ignored (watch, type);
 	if (ret) {
@@ -1450,7 +1456,7 @@ gpk_watch_process_require_restart_cb (PkRequireRestart *item, GpkWatch *watch)
 	}
 
 	/* add to list */
-	egg_warning ("adding %s to restart list", split[PK_PACKAGE_ID_NAME]);
+	egg_debug ("adding %s to restart list", split[PK_PACKAGE_ID_NAME]);
 	g_ptr_array_add (names, g_strdup (split[PK_PACKAGE_ID_NAME]));
 out:
 	g_free (package_id);
@@ -1499,7 +1505,7 @@ gpk_watch_adopt_cb (PkClient *client, GAsyncResult *res, GpkWatch *watch)
 		      "elapsed-time", &elapsed_time,
 		      NULL);
 
-	egg_warning ("%s finished (%s)", transaction_id, pk_role_enum_to_text (role));
+	egg_debug ("%s finished (%s)", transaction_id, pk_role_enum_to_text (role));
 
 	/* get the error */
 	error_code = pk_results_get_error_code (results);
